@@ -34,7 +34,7 @@ All classes inherit from :class:`github.GithubObject.GithubObject`.
 
 import logging
 
-from .MainClass import Github
+from .MainClass import Github, GithubIntegration
 from .GithubException import GithubException, BadCredentialsException, UnknownObjectException, BadUserAgentException, RateLimitExceededException, BadAttributeException
 from .InputFileContent import InputFileContent
 from .InputGitAuthor import InputGitAuthor
