@@ -47,6 +47,9 @@ class Milestone(Framework.TestCase):
         self.assertEqual(self.milestone.url, "https://api.github.com/repos/jacquev6/PyGithub/milestones/1")
         self.assertEqual(self.milestone.creator.login, "jacquev6")
 
+        # test __repr__() based on this attributes
+        self.assertEqual(self.milestone.__repr__(), 'Milestone(number=1)')
+
     def testEditWithMinimalParameters(self):
         self.milestone.edit("Title edited by PyGithub")
         self.assertEqual(self.milestone.title, "Title edited by PyGithub")
